| Home | Libraries | People | FAQ | More

### has_trivial_copy

    template <class T>
    struct has_trivial_copy : public true_type-or-false_type {};

    template <class T>
    struct has_trivial_copy_constructor : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) type with a trivial copy-constructor then inherits from true_type, otherwise inherits from false_type.

These two traits are synonyms for each other.

If a type has a trivial copy-constructor then the constructor has the same effect as copying the bits of one object to the other: calls to the constructor can be safely replaced with a call to `memcpy`.

Compiler Compatibility: If the compiler does not support partial-specialization of class templates, then this template can not be used with function types.

Without some (as yet unspecified) help from the compiler, has_trivial_copy will never report that a user-defined class or struct has a trivial constructor; this is always safe, if possibly sub-optimal. Currently (May 2011) compilers more recent than Visual C++ 8, GCC-4.3, Greenhills 6.0, Intel-11.0, and Codegear have the necessary compiler intrinsics to ensure that this trait "just works". You may also test to see if the necessary intrinsics are available by checking to see if the macro `BOOST_HAS_TRIVIAL_COPY` is defined.

C++ Standard Reference: 12.8p6.

Header: `#include <boost/type_traits/has_trivial_copy.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> `has_trivial_copy<int>` inherits from `true_type`.

> `has_trivial_copy<char*>::type` is the type `true_type`.

> `has_trivial_copy<int (*)(long)>::value` is an integral constant expression that evaluates to true.

> `has_trivial_copy<MyClass>::value` is an integral constant expression that evaluates to false.

> `has_trivial_copy<T>::value_type` is the type `bool`.